==> haskell-loch-th-0.2.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.2
id: loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
key: loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
license: BSD3
maintainer: tomi@nomi.cz
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
author: Tomas Janousek
exposed: True
indefinite: False
exposed-modules:
    Debug.Trace.LocationTH
abi: 9ec1060f42e22c7b98d46a2a990f6e8f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/loch-th-0.2.2
hs-libraries: HSloch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
depends:
    base-4.10.1.0 pretty-1.1.3.3 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loch-th-0.2.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.2
id: loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
key: loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
license: BSD-3-Clause
maintainer: tomi@nomi.cz
author: Tomas Janousek
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
abi: f2efb501bc846384684e0c769317a2c2
exposed: True
exposed-modules:
    Debug.Trace.LocationTH
import-dirs: /usr/lib/ghc-8.4.2/site-local/loch-th-0.2.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/loch-th-0.2.2
hs-libraries: HSloch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
depends:
    base-4.11.1.0 pretty-1.1.3.6 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             pretty-1.1.3.6=003e48b94caa84f26c31da01b81a0320
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
